#' Multiple Co-Inertia Analysis 
#' 
#' This function conduct multiple co-inertia analysis. This function esimate one set of loading vectors for a given datasets.
#' To estimate consequent loading vectors, put deflated datasets using previously estimated sets of loading vectors. 
#' @param Tdat n-by-p concatenated matrix of transformed data, \tilde{\mathbf{X}}_1, \ldots, \tilde{\mathbf{X}}_K, where p=\sum_{i=k}^K p_i.
#' @param ps K-by-1 vector containing all dimensions of each dataset.
#' @return This function returns a list object.
#' \item{a}{A length-K list contains the estimated loading vectors of K data matrices.}
#' \item{b}{A n-by-1 vector, the estimated synthetic reference vector.}
#' @seealso \code{\link{l0pmCIA}}, \code{\link{cv.l0pmCIA}}, \code{\link{plot.pmCIA}}
#' @examples
#' library(pmCIA)
#' data(demoData)
#' single.data <- list(demoData$X1[1:200,],demoData$X2[1:200,], demoData$X3[1:200,])
#' ps <- unlist(lapply(data, function(x) dim(x)[2]) ) 
#' res.mCIA <- mCIA(single.data, ps)
#' @export
mCIA = function(Tdat, ps){
  n = dim(Tdat)[1]
  K = length(ps)
  a <- NULL
  # estimate b
  mat.b = matrix(0, nrow=n, ncol=n)
  for (i in 1:K){
    ind1 = sum(ps[1:i]) - ps[i] + 1
    ind2 = sum(ps[1:i])
    mat.b = mat.b + Tdat[,ind1:ind2] %*% t(Tdat[,ind1:ind2])
  }
  b = rARPACK::eigs(mat.b, k=1)$vectors
  
  # estimaet as
  for (i in 1:K){
    ind1 = sum(ps[1:i]) - ps[i] + 1
    ind2 = sum(ps[1:i])
    a[[i]] = t(Tdat[,ind1:ind2])%*%b / norm(t(Tdat[,ind1:ind2])%*%b,"2")
  }
  return(list("a"= a, "b"=b))
}
