% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cv.l0pmCIA.R
\name{cv.l0pmCIA}
\alias{cv.l0pmCIA}
\title{Penalized multiple Co-Inertia Analysis for}
\usage{
cv.l0pmCIA(data, gridpt, nfold = 5, tL = NULL, n.penalty = FALSE,
  prop.test = 0, npc = 1, savefile = NULL)
}
\arguments{
\item{data}{A length-K list object containing data matrices \mathbf{X}_1, \ldots, \mathbf{X}_K.}

\item{gridpt}{A J-by-(K+2) matrix containing combinations of tuning parameters to investigate. Each row is one combination of (\lambda,stepsize, s_1,\ldots, s_K).}

\item{nfold}{Number of subgroups for the cross validation.}

\item{tL}{A length K list object containing transformed laplacian matrix for network penalties. k-th element of \code{tL} contains a transformed laplacian matrix of the network information for the k-th data matrix.}

\item{n.penalty}{Indicator variable to let the function know whether user wants to incorporate structured information existing among data matrices. Default value is \code{FALSE}.}

\item{prop.test}{A scalar between 0 and 1, it is  proportion of test data among the whole data, if user want to set aside the test dataset. Default value is 0.}

\item{npc}{A scaler value, a number of sets of loading vectors to estimate. Default value is 1.}

\item{savefile}{}
}
\value{
This function returns a list object "opt.results" containing npc number of lists named "opt.result". Each list contains following elements:
\item{a}{A length-K list containing the estimated loading vectors of K data matrices.}
\item{b}{A n-by-1 vector, the estimated synthetic reference vector.}
\item{test.objval/whole.objval}{Calculated objective value using the estimated loading vectors. If prop.test is nonzero, objective value is calculated using the test data.}
\item{opt.tune}{A combination of optimal tuning parameter selected by cross validation.}
}
\description{
This function conduct penalized multiple co-inertia analysis for a given set of tuning parameter values. This function esimate one set of loading vectors for a given datasets.
To estimate consequent loading vectors, put deflated datasets using previously estimated sets of loading vectors.
}
\examples{
library(pmCIA)
data(demoData)
s.gridpt <- genGridpt(s=c(50, 50, 50), 
                      edit = list(matrix(c(-10, 0, 10), ncol=1),matrix(c(-10, 0, 10), ncol=1),
                      matrix(c(-10, 0, 10), ncol=1)), 
                      n.steps=c(0,1,5))
n.gridpt <- genGridpt(s=c(50, 50, 50),
                       edit = list(matrix(c(-10, 0, 10), ncol=1),matrix(c(-10, 0, 10), ncol=1),
                       matrix(c(-10, 0, 10), ncol=1)),
                       n.steps=c(0,1,5), 
                       n.penalty = T, 
                       info.lambda = c(0,1,5,1))
single.data <- list(demoData$X1[1:200,],demoData$X2[1:200,], demoData$X3[1:200,])
res.sparse <- cv.l0pmCIA(singledata, s.gridpt)
res.network <- cv.l0pmCIA(singedata, n.gridpt, tL=demoData$tL, n.penalty=T)
}
\seealso{
\code{\link{mCIA}}, \code{\link{l0pmCIA}}, \code{\link{genGridpt}}, \code{\link{plot.pmCIA}}
}
