% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/genGridpt.R
\name{genGridpt}
\alias{genGridpt}
\title{Generating Grid Points for Cross Valdiation to Select Optimal Tuning Parameters of Penalized Multple Co-Inertia Analysis}
\usage{
genGridpt(s = c(50, 50, 50), edit = list(matrix(c(-10, 0, 10), ncol =
  1), matrix(c(-10, 0, 10), ncol = 1), matrix(c(-10, 0, 10), ncol = 1)),
  n.steps = c(0, 1, 5), n.penalty = FALSE, info.lambda = NULL)
}
\arguments{
\item{s}{A length-K vector, containing desired number of nonzero elements in the estimanted loading vectors of each K datasets.}

\item{edit}{A J-by-(K+2) matrix containing combinations of tuning parameters to investigate. Each row is one combination of (\lambda,stepsize, s_1,\ldots, s_K).}

\item{n.penalty}{Indicator variable to let the function know whether user wants to incorporate structured information existing among data matrices. Default value is \code{FALSE}.}

\item{info.lambda}{A vector with four elements, (v1, v2, v3, v4). Using this input, this function generates v3 number of lambda (tuning paramter for the network penalty) values between v1 and v2, with increaing rate v4.}

\item{nsteps}{A vector with three elements, (v1, v2, v3). Using this input, this function generates v3 evenly-distributed number of stepsize between v1 and v2.}

\item{tL}{A length K list object containing transformed laplacian matrix for network penalties. k-th element of \code{tL} contains a transformed laplacian matrix of the network information for the k-th data matrix.}
}
\value{
This function returns a matrix, each row is one combination of tuning parameters while each column stands for lambda, stepsize, desired number of nonzero elements in the estimated loading for the first data, ..., and desired number of nonzero elements in the estimated loading for K-th data.
}
\description{
This function generates a set of grid points of possible tuning parameters for cross validation procedure of penalized mCIA. User can manually generate the set of grid points instead of using this function.
}
\examples{
library(pmCIA)
data(demoData)
s.gridpt <- genGridpt(s=c(50, 50, 50), 
                      edit = list(matrix(c(-10, 0, 10), ncol=1),matrix(c(-10, 0, 10), ncol=1),
                      matrix(c(-10, 0, 10), ncol=1)), 
                      n.steps=c(0,1,5))
n.gridpt <- genGridpt(s=c(50, 50, 50),
                       edit = list(matrix(c(-10, 0, 10), ncol=1),matrix(c(-10, 0, 10), ncol=1),
                       matrix(c(-10, 0, 10), ncol=1)),
                       n.steps=c(0,1,5), 
                       n.penalty = T, 
                       info.lambda = c(0,1,5,1))
single.data <- list(demoData$X1[1:200,],demoData$X2[1:200,], demoData$X3[1:200,])
res.sparse <- cv.l0pmCIA(singledata, s.gridpt)
res.network <- cv.l0pmCIA(singedata, n.gridpt, tL=demoData$tL, n.penalty=T)
}
\seealso{
\code{\link{mCIA}}, \code{\link{l0pmCIA}}, \code{\link{genGridpt}}, \code{\link{plot.pmCIA}}
}
