% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/l0pmCIA.R
\name{l0pmCIA}
\alias{l0pmCIA}
\title{Penalized multiple Co-Inertia Analysis}
\usage{
l0pmCIA(Tdat, ps, s, step = 0.1, n.penalty = FALSE, tL = NULL,
  lambda = NULL, threshold = 0.001, max_iter = 300)
}
\arguments{
\item{Tdat}{n-by-p concatenated matrix of transformed data, \tilde{\mathbf{X}}_1, \ldots, \tilde{\mathbf{X}}_K, where p=\sum_{i=k}^K p_i.}

\item{ps}{K-by-1 vector containing all dimensions of each dataset.}

\item{s}{K-by-1 vector containing number of desired nonzero element in each dataset.}

\item{step}{A scaler value used as a stepsize for the gradient descent algorithm. Default value is \code{0.1}.}

\item{n.penalty}{Indicator variable to let the function know whether user wants to incorporate structured information existing among data matrices. Default value is \code{FALSE}.}

\item{tL}{A length K list object containing transformed laplacian matrix for network penalties. k-th element of \code{tL} contains a transformed laplacian matrix of the network information for the k-th data matrix.}

\item{lambda}{A scaler value used as a tuning parameter for the network penalty.}

\item{threshold}{A scaler value used as a threshold for the algorithm. Default value is \code{1e-3}.}

\item{max_iter}{A scaler value used as a maximum number of iterations of the algorithm. Default value is \code{300}.}
}
\value{
This function returns a list object.
\item{a}{A length-K list contains the estimated loading vectors of K data matrices.}
\item{b}{A n-by-1 vector, the estimated synthetic reference vector.}
\item{mark}{An indicator that tells about whether the algorithm was forced to finish due to the oscillation. \code{1} means the }
}
\description{
This function conduct penalized multiple co-inertia analysis for a given set of tuning parameter values. This function esimate one set of loading vectors for a given datasets.
To estimate consequent loading vectors, put deflated datasets using previously estimated sets of loading vectors.
}
\examples{
library(pmCIA)
data(demoData)
single.data <- cbind(demoData$X1[1:200,],demoData$X2[1:200,], demoData$X3[1:200,])
ps <- unlist(lapply(data, function(x) dim(x)[2]) ) 
s <- rep(50, length(ps))
lambda <- 0.8
res.spare <- l0pmCIA(single.data, ps, s)
res.network <- l0pmCIA(single.data, ps, s, n.penalty=T, tL=demoData$tL, lambda=lambda) 
}
\seealso{
\code{\link{mCIA}}, \code{\link{cv.l0pmCIA}}, \code{\link{plot.pmCIA}}
}
